@@ -92,7 +92,7 @@ int	eh_standout = YES;		/* ehist default for standout         */
 int	eh_bol      = NO;		/* start ehist at beginning of line   */
 int	eh_verify   = NO;		/* use ehist with history meta-chars  */
 
-char	*e_tonextword(), *e_toprevword();
+char	*e_tonextword(register char *ip), *e_toprevword(char *ip, char *string);
 
 int eparam (struct ep_context *cx, int *update, int *nextcmd, char *nextpset);
 
@@ -452,7 +452,7 @@ e_repaint (void)
 		 * label columns (if desired).
 		 */
 		p = parmlist[keyid]->p_prompt;
-		if (p == NULL || *p == NULL)
+		if (p == NULL || *p == '\0')
 		    p = static_prompt;
 
 		/* e_indent_prompt (p, promptbuf, startcol); */
@@ -705,7 +705,7 @@ e_check_vals (
   char    *string
 )
 {
-	char *gquery();		/* declare gquery as returning a pointer  */
+	char *gquery(struct param *pp, char *string);		/* declare gquery as returning a pointer  */
 	char *errstr;		/* pointer to the error string (or 0)     */
 	char message[SZ_LINE+1];/* error message string			  */
 	int  badnews;		/* a flag if an array element is in error */
@@ -722,7 +722,7 @@ e_check_vals (
 
 	if (isarray) {
 	    char    outstring[G_MAXSTRING];
-	    char    *in, *e_getfield();
+	    char    *in, *e_getfield(register char *ip, char *outstr, int maxch);
 	    int	    first, nelem, flen;
 	    
 	    /* Get the length of the first dimension, and the starting point.
@@ -1141,7 +1141,7 @@ editstring (
   int	eparam 				/* flag to indicate eparam or ehis  */
 )
 {
-	char	oldchar;		/* save old character after delete  */
+	char	oldchar = '\0';		/* save old character after delete  */
 	char    oldword[G_MAXSTRING];   /* save the deleted word            */
 	char    oldline[G_MAXSTRING];	/* save the deleted line            */
 	char	tempstr[G_MAXSTRING];
