@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -31,10 +33,8 @@ extern	int	cldebug;
  *   and read from the current standard input if it is.
  * Call error() if get ferror while reading or can't open list file.
  */
-struct operand
-readlist (
-  struct param *pp
-)
+struct operand 
+readlist (struct param *pp)
 {
 	struct	operand result;
 	int	bastype;
@@ -79,9 +79,9 @@ again:	    fgets (line, SZ_LINE, pp->p_listfp);
 		result = makeop (eofstr, OT_STRING);
 
 	    } else {
-		char *index(), *nlp, *ip;
+		char *nlp, *ip;
 
-		nlp = index (line, '\n');
+		nlp = strchr (line, '\n');
 		if (nlp != NULL)
 		    *nlp = '\0';
 
@@ -112,10 +112,8 @@ again:	    fgets (line, SZ_LINE, pp->p_listfp);
  * We assume (pp->p_type & PT_LIST) but do check that the file is not
  * already closed and that we're not closing the real stdin.
  */
-void
-closelist (
-  register struct param *pp
-)
+void 
+closelist (register struct param *pp)
 {
 	if (pp->p_listfp != NULL) {
 	    if (pp->p_listfp != stdin)
