@@ -63,7 +63,7 @@ int	cldebug = 0;		/* print out lots of goodies if > 0	*/
 int	cltrace = 0;		/* trace instruction execution if > 0	*/
 
 static	funcptr_t old_onipc;	/* X_IPC handler chained to onint()	*/
-static	long *jumpcom;		/* IRAF Main setjmp/longjmp buffer	*/
+static	XINT *jumpcom;		/* IRAF Main setjmp/longjmp buffer	*/
 static	jmp_buf jmp_save;	/* save IRAF Main jump vector		*/
 static	jmp_buf jmp_clexit;	/* clexit() jumps here			*/
 static	int intr_sp;		/* interrupt save stack pointer		*/
@@ -84,12 +84,12 @@ long	cpustart, clkstart;	/* starting cpu, clock times if bkg	*/
 int	logout_status = 0;	/* optional status arg to logout()	*/
 
 
-static void execute();
-static void login(), logout();
-static void startup(), shutdown();
+static void execute(int mode);
+static void login(char *cmd), logout(void);
+static void startup(void), shutdown(void);
 
 static void onint (int *vex, int (**next_handler)(void));
-extern int yyparse();
+extern int yyparse(void);
 
 
 /* C_MAIN -- Called by the SPP procedure in cl.x to fire up the CL.
@@ -109,7 +109,7 @@ c_main (
 	 * ourselves during normal execution, but when the CL exits we are
 	 * not prepared to deal with errors occuring during shutdown.
 	 */
-	XMJBUF (&bp);  jumpcom = (long *)&Memc[bp];
+	XMJBUF (&bp);  jumpcom = (XINT *)&Memc[bp];
 	cl_amovi ((int *)jumpcom, (int *)jmp_save, LEN_JUMPBUF);
 
 	/* Init clexit() in case we have to panic stop.  */
@@ -252,7 +252,7 @@ execute (int mode)
 {
 	int	parsestat;
 	XINT	old_parhead;
-	char	*curcmd();
+	char	*curcmd(void);
 
 	alldone = 0;
 	gologout = 0;
