@@ -268,8 +268,8 @@ query (struct param *pp)
 	char	buf[SZ_PROMPTBUF+1];
 	struct	operand o;
 	int	bastype, batch, arrflag, offset=0, n_ele, max_ele, fd;
-	char	*nlp, *nextstr();
-	char	*bkg_query(), *query_status;
+	char	*nlp, *nextstr(char **pbuf, FILE *fp);
+	char	*bkg_query(char *obuf, int maxch, register struct param *pp), *query_status;
 	char	*abuf;
 
 	bastype = pp->p_type & OT_BASIC;
@@ -537,7 +537,7 @@ testval:
 char *
 nextstr (char **pbuf, FILE *fp)
 {
-	char	*p, *nxtchr();
+	char	*p, *nxtchr(char *p, FILE *fp);
 	static	char	tbuf[SZ_LINE];
 	char	quote;
 	int	cnt;
@@ -751,7 +751,7 @@ bkg_query (
 {
 	char	bqfile[SZ_PATHNAME], qrfile[SZ_PATHNAME];
 	int	waitime, delay;
-	char	*envget(), *fgets_status;
+	char	*fgets_status;
 	FILE	*fp, *in;
 
 	if (notify())
@@ -866,7 +866,6 @@ void
 get_bkgqfiles (int bkgno, int pid, char *bkg_query_file, char *query_response_file)
 {
 	int	filecode;
-	char	*envget();
 
 	if (envget (UPARM) == NULL)
 	    cl_error (E_UERR,
