@@ -88,7 +88,7 @@ int	pr_pno = 1;			/* incremented for each connect	*/
 int	sz_prcache = 2;			/* nprocess slots in cache	*/
 struct	process pr_cache[MAXSUBPROC];
 struct	process *pr_head = NULL, *pr_tail = NULL;
-extern	char *findexe();
+extern	char *findexe(struct package *pkg, char *pkg_path);
 
 static void pr_pdisconnect (struct process *pr);
 static void pr_tohead (struct process *pr);
@@ -127,7 +127,7 @@ pr_connect (
 	register int	pid;
 
 	/* Connect subprocess. */
-	if ((pid = pr_pconnect (process, in, out)) == NULL)
+	if ((pid = pr_pconnect (process, in, out)) == 0)
 	    c_erract (EA_ERROR);
 
 
@@ -193,7 +193,7 @@ pr_pconnect (
 )
 {
 	struct process *pr;
-	struct	process *pr_findproc();
+	struct	process *pr_findproc(char *process);
 	struct	_finfo fi;
 	int	fd_in, fd_out;
 
@@ -225,7 +225,7 @@ pr_pconnect (
 	    /* Get process slot. */
 	    for (pr=pr_tail;  pr != NULL;  pr=pr->pr_up)
 		if (!pr_busy(pr)) {
-		    if (pr->pr_pid != NULL)
+		    if (pr->pr_pid != 0)
 			pr_pdisconnect (pr);
 		    break;
 		}
@@ -239,7 +239,7 @@ pr_pconnect (
 	    if (cltrace)
 		eprintf ("\t----- connect to %s -----\n", process);
 	    intr_disable();
-	    if ((pr->pr_pid = c_propen (process, &fd_in, &fd_out)) == NULL) {
+	    if ((pr->pr_pid = c_propen (process, &fd_in, &fd_out)) == 0) {
 		intr_enable();
 		return (0);
 	    }
