@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -52,15 +54,12 @@ static	int nscan_val=0;	/* value returned by NSCAN intrinsic	*/
  * error() may be called on various conditions.
  */
 void
-cl_scan (
-  int	nargs,
-  char	*source
-)
+cl_scan (int nargs, char *source)
 {
 	char	buf[SZ_LINE];
 	char	*bp, *start, c;
 	char	*pk, *t, *p, *f;
-	char	field;
+	char	field = '\0';
 	struct	operand o;
 	struct	param *pp;
 	int	eoftst;
@@ -198,11 +197,7 @@ cl_scan (
  * statement is used to decode the input text.
  */
 void
-cl_scanf (
-  char	*format,
-  int	nargs,
-  char	*input
-)
+cl_scanf (char *format, int nargs, char *input)
 {
 	int	nscan_val, eoftst, n;
 	char	*pk, *t, *p, *f;
@@ -335,14 +330,11 @@ get_nscanval (void)
  * buffer.
  */
 void
-lentst (
-  char	*buf
-)
+lentst (char *buf)
 {
-	char	*index();
 	char	*bp;
 
-	bp = index (buf, '\n');
+	bp = strchr (buf, '\n');
 	if (bp != NULL)
 	    *bp = '\0';
 	else
