@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_libc
 #define import_stdio
@@ -263,7 +265,7 @@ int
 defpac (char *pkname)
 {
 	switch ((XINT) pacfind (pkname)) {
-	case NULL:
+	case 0:
 	    return (NO);
 	case ERR:
 	    cl_error (E_UERR, e_pckambig, pkname);
@@ -334,18 +336,18 @@ deftask (char *task_spec)
 	if (pkname[0] != '\0') {	/* explicit package named	*/
 	    if ((pkp = pacfind (pkname)) == NULL)
 		cl_error (E_UERR, e_pcknonexist, pkname);
-	    if ((stat = (XINT) ltaskfind (pkp, ltname, 1)) == NULL)
+	    if ((stat = (XINT) ltaskfind (pkp, ltname, 1)) == 0)
 		return (NO);
 
 	} else {			/* search all packages		*/
 	    pkp = reference (package, pachead);
-	    stat = NULL;
+	    stat = 0;
 
 	    while (pkp != NULL) {
 		stat = (XINT) ltaskfind (pkp, ltname, 1);
 		if (stat == ERR)
 		    break;
-		else if (stat != NULL)
+		else if (stat != 0)
 		    return (YES);
 		pkp = pkp->pk_npk;
 	    }
@@ -353,7 +355,7 @@ deftask (char *task_spec)
 
 	if (stat == ERR)
 	    cl_error (E_UERR, e_tambig, ltname);
-	if (stat != NULL)
+	if (stat != 0)
 	    return (YES);
 	return (NO);
 }
@@ -398,7 +400,6 @@ addltask (struct package *pkp, char *ptname, char *ltname, int redef)
 {
 	register char *cp;
 	register struct ltask *ltp;
-	char	*rindex();
 	char	*ltbase;
 	int	flags;
 
@@ -418,7 +419,7 @@ addltask (struct package *pkp, char *ptname, char *ltname, int redef)
 
 	/* Check for trailing .bt etc. specs on logical task name.
 	 */
-	if ((cp = rindex (ltbase, '.')) != NULL) {
+	if ((cp = strrchr (ltbase, '.')) != NULL) {
 	    /* replace '.' with '\0' in hopes of finding valid specs.
 	     * if invalid, put back before giving error diagnostic.
 	     */
@@ -451,7 +452,7 @@ addltask (struct package *pkp, char *ptname, char *ltname, int redef)
 	/* Check for trailing .cl spec in physical task name to indicate
 	 * a script task, or a .par to indicate a pset task.
 	 */
-	if (ptname && (cp = rindex (ptname, '.')) != NULL) {
+	if (ptname && (cp = strrchr (ptname, '.')) != NULL) {
 	    cp++;
 	    if (!strcmp (cp, "cl"))
 		flags |= LT_SCRIPT;
