@@ -270,7 +270,7 @@ cl_locate (char *task_spec, int first_only)
 	    }
 	}
 
-	if (found == NULL)
+	if (found == 0)
 	    oprintf ("%s: task not found.\n", task_spec);
 	else
 	    oprintf ("\n");
@@ -2013,7 +2013,7 @@ cledit (void)
 	char	oscmd[SZ_LINE], os_filelist[SZ_LINE];
 	char	osfn[SZ_PATHNAME];
 	struct	operand o;
-	char	*envget();
+	char	*envget(char *name);
 	int	n;
 
 	pfp = newtask->t_pfp;
@@ -2292,9 +2292,9 @@ setbuiltins (register struct package *pkp)
 {
 	/* Debugging functions are in debug.c.
 	 */
-	extern void d_f(), d_l(), d_d(), d_off(), d_on(), d_p(), d_t();
-	extern void d_asmark(), d_assemble(), d_prof(), d_trace();
-	extern void pr_listcache();
+	extern void d_f(void), d_l(void), d_d(void), d_off(void), d_on(void), d_p(void), d_t(void);
+	extern void d_asmark(void), d_assemble(void), d_prof(void), d_trace(int value);
+	extern void pr_listcache(FILE *fp);
 
 	static struct builtin {
 		char	*b_name;
