@@ -148,7 +148,7 @@ lexicon (void)
 	char	*bkgerr = "ERROR: cannot submit background job inside {}\n";
 	register int	ch, cch;
 	register int	token;
-	int	stringtok, identifier, setlevel;
+	int	stringtok = 1, identifier = 1, setlevel = 0;
 	int	clswitch;
 	char	*op;
 
@@ -650,7 +650,7 @@ eatwhite_:
 /* LEXINIT -- Initialize the internal state variables of the lexical analyzer,
  * e.g. when processing is interrupted by an interrupt.
  */
-int 
+void
 lexinit (void)
 {
 	if (lexmodes() && !lex_cpumodeset (currentask->t_in)) {
