@@ -25,16 +25,16 @@ define	REPLICATE		Memi[$1+1]
 define	NSAMPLE_LINES		Memi[$1+2]
 define	LUT			Memi[$1+3]
 define	PERIM			Memi[$1+4]
-define	XMAG			Memr[$1+5]
-define	YMAG			Memr[$1+6]
-define	CONTRAST		Memr[$1+7]
-define	Z1			Memr[$1+8]
-define	Z2			Memr[$1+9]
-define	GREYSCALE_FRACTION	Memr[$1+10]
-define	IMAGE_FRACTION		Memr[$1+11]
-define	GRAPHICS_FRACTION	Memr[$1+12]
-define	X_BA			Memr[$1+13]
-define	Y_BA			Memr[$1+14]
+define	XMAG			Memr[P2R($1+5)]
+define	YMAG			Memr[P2R($1+6)]
+define	CONTRAST		Memr[P2R($1+7)]
+define	Z1			Memr[P2R($1+8)]
+define	Z2			Memr[P2R($1+9)]
+define	GREYSCALE_FRACTION	Memr[P2R($1+10)]
+define	IMAGE_FRACTION		Memr[P2R($1+11)]
+define	GRAPHICS_FRACTION	Memr[P2R($1+12)]
+define	X_BA			Memr[P2R($1+13)]
+define	Y_BA			Memr[P2R($1+14)]
 define	UFILE			Memc[P2C($1+15)]
 define	ZTRANS			Memc[P2C($1+55)]
 define	DEVICE			Memc[P2C($1+95)]
