@@ -58,11 +58,6 @@ main (int argc, char *argv[])
 	    hlength = htab[hindex].length;
 	    dp = data = htab[hindex].code;
 
-	    if (DEBUG)
-		printf ("'%c' %4d: index=%4d len=%3d dlen=%3d %s\n",
-		    ch, hnum, hindex, hlength, strlen(data),
-		    (strlen(data) % 2) ? "ERROR" : "");
-
 	    /* Now decode the stroke data into X-Y pairs, first pair is for
 	     * proportional spacing.
 	     */
@@ -70,8 +65,6 @@ main (int argc, char *argv[])
 	    maxx = (*dp - 'R'); dp++;
 	    chrwid[charnum++] = min (32, maxx - minx + 5);
 
-	    if (DEBUG) printf("\twidth (%02d) (%d,%d)\n", maxx-minx,minx,maxx);
-
 	    /* Next pair is the initial move.  The Y coords are flipped
 	     * for what we need so fix that every place we get a Yval.
 	     */
@@ -81,8 +74,6 @@ x = (ch == '1' ? x-3: x);
 	    y = YCOORD(); dp++;
 	    chrtab[idx++] = ENCODE(pen, x, y);
 
-	    if (DEBUG) printf ("\tmove (%3d,%3d) '%s'\n", x, y, dp);
-
 	    /* The remainder of the codes are move/draw strokes.
 	     */
 	    for (i=0; i < (hlength-2); i++) {
@@ -99,10 +90,6 @@ x = (ch == '1' ? x-3: x);
 		y = YCOORD(); dp++;
 
 		chrtab[idx++] = ENCODE(pen, x, y);
-
-	        if (DEBUG) 
-		    printf("\t%s (%3d,%3d) => %6d\n",
-			pen?"draw":"move", x, y, ENCODE(pen,x,y));
 	    }
 	    chrtab[idx++] = ENCODE(0, 0, 0);
 	    ch++;
@@ -117,15 +104,21 @@ x = (ch == '1' ? x-3: x);
 }
 
 
-int 
-print_index (int *idxtab, int N)
+static void
+print_index (
+    int	*idxtab, 
+    int N
+)
 {
 	register int i, j, start=1, end=5;
+        char ch;
 
 	for (i=0; i < N; ) {
 	    printf ("data    (chridx(i), i=%03d,%03d) /", start, min(N,end));
-	    for (j=0; j < 5 && i < N; j++)
-		printf ("%5d%c", idxtab[i++], (j<4 && i<N ? ',' : '/'));
+	    for (j=0; j < 5 && i < N; j++) {
+                ch = (j<4 && i<N ? ',' : '/');
+		printf ("%5d%c", idxtab[i++], ch);
+            }
 	    printf ("\n");
 	    start = end + 1;
 	    end += 5;
@@ -133,15 +126,21 @@ print_index (int *idxtab, int N)
 }
 
 
-int 
-print_widths (int *wtab, int N)
+static void
+print_widths (
+    int	*wtab,
+    int	N
+)
 {
 	register int i, j, start=1, end=5;
+        char ch;
 
 	for (i=0; i < N; ) {
 	    printf ("data    (chrwid(i), i=%03d,%03d) /", start, min(N,end));
-	    for (j=0; j < 5 && i < N; j++)
-		printf ("%5d%c", wtab[i++], (j<4 && i<N ? ',' : '/'));
+	    for (j=0; j < 5 && i < N; j++) {
+                ch = (j<4 && i<N ? ',' : '/');
+		printf ("%5d%c", wtab[i++], ch);
+            }
 	    printf ("\n");
 	    start = end + 1;
 	    end += 5;
@@ -149,15 +148,21 @@ print_widths (int *wtab, int N)
 }
 
 
-int 
-print_strokes (int *strtab, int N)
+static void
+print_strokes (
+    int	*strtab,
+    int	N
+)
 {
 	register int i, j, start=1, end=5;
+        char ch;
 
 	for (i=0; i < N; ) {
 	    printf ("data    (chrtab(i), i=%04d,%04d) /", start, min(N,end));
-	    for (j=0; j < 5 && i < N; j++)
-		printf ("%6d%c", strtab[i++], (j<4 && i<N ? ',' : '/'));
+	    for (j=0; j < 5 && i < N; j++) {
+                ch = (j<4 && i<N ? ',' : '/');
+		printf ("%6d%c", strtab[i++], ch);
+            }
 	    printf ("\n");
 	    start = end + 1;
 	    end += 5;
@@ -165,10 +170,12 @@ print_strokes (int *strtab, int N)
 }
 
 
-int 
-print_prologue (int nidx, int nchar)
+static void
+print_prologue (
+    int	nidx,
+    int	nchar
+)
 {
-
 printf ("# CHRTAB -- Table of strokes for the printable ASCII characters.  Each\n");
 printf ("# character is encoded as a series of strokes.  Each stroke is ex-\n");
 printf ("# pressed by a single integer containing the following bitfields:\n");
