@@ -9,8 +9,13 @@ int	spoolfd = 0;
  * it, delete the file, edit the Makefile, and change the reference to
  * zzrdks in irafks.x to zardks.
  */
-int 
-zzrdks_ (int *chan, short *buf, int *maxb, int *off)
+void
+zzrdks_ (
+    int	  *chan,
+    short *buf,
+    int	  *maxb,
+    int	  *off
+)
 {
 	int	status;
 
