@@ -1,5 +1,5 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
- */
+*/
 
 #define import_spp
 #define	import_libc
@@ -7,11 +7,13 @@
 #include <iraf.h>
 
 /* C_FNROOT -- Extract the root filename substring from a filename.
- */
-c_fnroot (vfn, root, maxch)
-char	*vfn;			/* filename			*/
-char	*root;			/* root filename (output)	*/
-int	maxch;			/* max chars out		*/
+*/
+int
+c_fnroot (
+  char	*vfn,			/* filename			*/
+  char	*root,			/* root filename (output)	*/
+  int	maxch			/* max chars out		*/
+)
 {
 	XCHAR	spp_root[SZ_FNAME+1];
 	XINT	x_maxch = SZ_FNAME, nchars;
