@@ -1,9 +1,10 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
 */
 
+#include <ctype.h>
+
 #define	import_spp
 #define import_libc
-#define	import_ctype
 #define	import_lexnum
 #define	import_xnames
 #include <iraf.h>
@@ -31,7 +32,7 @@ c_lexnum (
 {
 	register char *ip;
 	register XCHAR *op, ch, ndigits;
-	PKCHAR	 numbuf[SZ_FNAME];
+	XCHAR	 numbuf[SZ_FNAME];
 	XINT	 ip_start = 1, x_toklen = *toklen;
 	int      status;
 
