@@ -4,6 +4,7 @@
 #define	import_spp
 #define	import_libc
 #define import_knames
+#define	import_kproto
 #include <iraf.h>
 
 
@@ -20,11 +21,11 @@ c_vfnbrk (
 )
 {
 	XCHAR	sppvfn[SZ_PATHNAME];
-	XINT    x_root = *root, x_extn = extn;
+	XINT    x_root, x_extn;
 
 	ZFNBRK (c_strupk(vfn,sppvfn,SZ_PATHNAME), &x_root, &x_extn);
 
 	/* Make offsets zero-indexed. */
-	*root -= 1;
-	*extn -= 1;
+	*root = x_root - 1;
+	*extn = x_extn - 1;
 }
