@@ -1,10 +1,11 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
 */
 
+#include <stdarg.h>
+
 #define	import_spp
 #define	import_libc
 #define	import_stdio
-#define	import_stdarg
 #include <iraf.h>
 
 
@@ -15,11 +16,8 @@ eprintf (char *format, ...)
 {
 	va_list	argp;
 
-	extern void u_doprnt();
-
-
 	va_start (argp, format);
-	u_doprnt (format, &argp, stderr);
+	vfprintf (stderr, format, argp);
 	va_end (argp);
 	(void) fflush (stderr);
 }
