@@ -1,11 +1,12 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
 */
 
+#include <stdarg.h>
+
 #define	import_spp
 #define	import_libc
 #define	import_xnames
 #define	import_stdio
-#define	import_stdarg
 #include <iraf.h>
 
 #define	SZ_OBUF		SZ_COMMAND	/* sz intermediate buffer	*/
@@ -26,8 +27,6 @@ sprintf (char *str, char *format, ...)
 	XINT x_fd, x_maxch = SZ_OBUF, x_mode = NEW_FILE;
 	va_list	argp;
 
-	extern int  u_doprnt();
-
 
 	va_start (argp, format);
 
@@ -42,7 +41,7 @@ sprintf (char *str, char *format, ...)
 	x_fd = STROPEN (fiobuf, &x_maxch, &x_mode);
 
 	/* Format the data into obuf.  */
-	u_doprnt (format, &argp, FDTOFP(x_fd));
+	vfprintf (FDTOFP(x_fd), format, argp);
 
 	/* FIO does not write the EOS until the string file is closed.
 	 * Move obuf to str if it is not already there.
