@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <stdlib.h>
+
 #define	import_spp
 #include <iraf.h>
 
@@ -9,5 +11,5 @@
 XINT
 abs_ (XINT *a)
 {
-	return (abs(a));
+	return (abs(*a));
 }
