@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_knames
 #include <iraf.h>
@@ -8,9 +10,11 @@
 /* ACLRC -- Clear a block of memory.
  * [Specially optimized for Sun/IRAF].
  */
-ACLRC (a, n)
-XCHAR	*a;
-XINT	*n;
+void
+ACLRC (
+  XCHAR	*a,
+  XINT	*n
+)
 {
 	memset ((char *)a, 0, *n * sizeof(*a));
 }
