@@ -1,6 +1,8 @@
 /* Copyright(c) 1986 Association of Universities for Research in Astronomy Inc.
  */
 
+#include <string.h>
+
 #define import_spp
 #define import_knames
 #include <iraf.h>
@@ -8,6 +10,7 @@
 /* ACLRI -- Clear a block of memory.
  * [Specially optimized for Sun/IRAF].
  */
+void
 ACLRI (
   XINT	*a,
   XINT	*n
