@@ -1,15 +1,24 @@
 #include <stdio.h>
-#include <ctype.h>
+
 #define	import_spp
 #define	NOKNET
-#define	import_knames
+#define	import_kproto
+#define import_kernel
+#ifndef NOVOS
+#define NOLIBCNAMES
+#define import_libc
+#define import_vosproto
+#endif
 #include <iraf.h>
 
+#include "../bootProto.h"
+
+char *_os_getenv (char *envvar, char *outstr, int maxch);
+
 #define	SZ_FBUF		512		/* File i/o buffer size		*/
 
 #include <sys/time.h>
 
-
 # ifdef FINIT
 int	bdebug = 0;			/* print debug stuff		*/
 int	osfiletype;			/* type of single output file	*/
@@ -21,8 +30,3 @@ extern	int osfiletype;
 extern	XCHAR text[];
 extern	XCHAR *txop;
 # endif
-
-char	*vfn2osfn(char *vfn, int new);
-char	*osfn2vfn(char *osfn);
-char	*os_strpak(short int *sppstr, char *cstr, int maxch);
-XCHAR	*os_strupk(char *str, short int *outstr, int maxch);
