@@ -3,15 +3,8 @@
 
 #include <stdio.h>
 #include <string.h>
-#define	NOLIBCNAMES
-#define	import_spp
-#define	import_libc
-#define	import_xnames
-#define	import_knames
-#include <iraf.h>
 #include "bootlib.h"
 
-
 static	char	vfn[SZ_PATHNAME+1];
 
 #ifdef NOVOS
@@ -46,27 +39,23 @@ osfn2vfn (
 	XINT	x_maxch = SZ_PATHNAME;
 	XINT	x_mode, vp, nchars;
 
-	extern  void _envinit(void);
-
-
 	_envinit();
 	
 	os_strupk ("./", x_vfn, SZ_PATHNAME);
 	x_mode = VFN_UNMAP;
-	iferr (vp = VFNOPEN (x_vfn, (integer *)&x_mode)) {
+	iferr (vp = VFNOPEN (x_vfn, &x_mode)) {
 	    vp = 0;
 	    goto err_;
 	}
 
 	strcpy ((char *)x_osfn, osfn);
-	iferr (nchars = VFNUNMAP ((integer *)&vp, x_osfn, x_vfn, 
-	    (integer *)&x_maxch))
-	        goto err_;
+	iferr (nchars = VFNUNMAP (&vp, x_osfn, x_vfn, &x_maxch))
+	    goto err_;
 	if (nchars < 0)
 	    goto err_;
 
 	x_mode = VFN_NOUPDATE;
-	VFNCLOSE ((integer *)&vp, (integer *)&x_mode);
+	VFNCLOSE (&vp, &x_mode);
 
 	os_strpak (x_vfn, vfn, SZ_PATHNAME);
 	return (vfn);
@@ -74,7 +63,7 @@ osfn2vfn (
 err_:
 	fprintf (stderr, "cannot unmap filename `%s'\n", osfn);
 	if (vp > 0)
-	    VFNCLOSE ((integer *)&vp, (integer *)&x_mode);
+	    VFNCLOSE (&vp, &x_mode);
 
 	strcpy (vfn, osfn);
 	return (vfn);
