@@ -4,8 +4,6 @@
 #include <fcntl.h>
 #include "bootlib.h"
 
-extern 	int  os_createfile (char *fname, int mode, int type);
-
 
 /* OS_OPEN -- Open or create a host system file for reading or writing (text
  * and binary disk files only).
@@ -17,11 +15,9 @@ os_open (
   int	type 			/* file type			*/
 )
 {
-	extern	char *vfn2osfn();
-
 	if (mode == 0) {
 	    osfiletype = BINARY_FILE;
-	    return (open (vfn2osfn (vfn, 0), 0));
+	    return (open (vfn2osfn (vfn, 0), O_RDONLY));
 	} else if (mode == 1) {
 	    return (os_createfile (vfn, mode, type));
 	} else
