@@ -18,12 +18,12 @@ static	long os_timezone(void);
  * daylight savings time (1 hour), and file times will come out a bit off
  * but it probably won't matter.
  */
-long
-os_utime (long iraf_time)
+time_t
+os_utime (time_t iraf_time)
 {
 	time_t	time_var, lst;
 
-	lst = (time_t)iraf_time;
+	lst = iraf_time;
 	
 	/* Add minutes westward from GMT */
 	time_var = lst + os_timezone();
@@ -32,20 +32,20 @@ os_utime (long iraf_time)
 	if (localtime(&lst)->tm_isdst)
 	    time_var += 60L * 60L;
 
-	return ((long)time_var + SECONDS_1970_TO_1980);
+	return (time_var + SECONDS_1970_TO_1980);
 }
 
 
 /* OS_ITIME -- Convert UNIX time (gmt, epoch 1970) to IRAF time (lst, epoch
  * 1980).	[MACHDEP]
  */
-long
-os_itime (long unix_time)
+time_t
+os_itime (time_t unix_time)
 {
 	struct	tm *localtime(const time_t *);
 	time_t	time_var, gmt;
 
-	gmt = (time_t)unix_time;
+	gmt = unix_time;
 	
 	/* Subtract minutes westward from GMT */
 	time_var = gmt - os_timezone();
@@ -54,7 +54,7 @@ os_itime (long unix_time)
 	if (localtime(&gmt)->tm_isdst)
 	    time_var -= 60L * 60L;
 
-	return ((long)time_var - SECONDS_1970_TO_1980);
+	return time_var - SECONDS_1970_TO_1980;
 }
 
 
