@@ -86,7 +86,7 @@ h_updatelibrary (
 )
 {
 	char	cmd[SZ_CMD+1], *args;
-	int	exit_status, baderr, npass;
+	int	exit_status, baderr;
 	int	nsources, nfiles, ndone, nleft;
 	int	hostnames, status;
 	char	libfname[SZ_PATHNAME+1];
@@ -184,10 +184,10 @@ h_updatelibrary (
 	 * are typically processed in each iteration.
 	 */
 	args  = &cmd[strlen(cmd)];
-	nleft = totfiles;
-	ndone = 0;
 
-	for (npass=0; nleft > 0; npass++) {
+	for (nleft = totfiles, ndone = 0;
+	     nleft > 0;
+	     nleft -= nfiles, ndone += nfiles) {
 
 	    /* Add as many filenames as will fit on the command line.  */
 	    nfiles = add_objects (cmd, SZ_CMD, &flist[ndone], nleft,
@@ -226,9 +226,6 @@ h_updatelibrary (
 	     */
 	    (*args) = EOS;
 
-	    ndone += nfiles;
-	    nleft -= nfiles;
-
 	}
 
 	return (exit_status);
@@ -278,7 +275,7 @@ h_incheck (
     char  *dir 			/* where to put the file	*/
 )
 {
-	char    backup[SZ_PATHNAME+1];
+	char    backup[SZ_PATHNAME+5];
 	char    path[SZ_PATHNAME+1];
 	char	fname[SZ_PATHNAME+1];
 	char	*osfn, *ip;
@@ -387,7 +384,7 @@ h_outcheck (
 	 * alternate source for the local file, which must be preserved.
 	 */
 	if (access (fname, 0) != -1) {
-	    char    backup[SZ_PATHNAME+1];
+	    char    backup[SZ_PATHNAME+5];
 
 	    if (clobber) {
 		if (debug) {
