@@ -38,7 +38,7 @@ do_mkpkg (
 	}
 
 	if (open_mkpkgfile (cx) == ERR) {
-	    char    fname[SZ_PATHNAME+1];
+	    char    fname[2*SZ_PATHNAME+1];
 	    struct  context *save_cx;
 
 	    save_cx = topcx;
@@ -208,7 +208,7 @@ next_:	    tok = gettok (cx, token, SZ_FNAME);
 		parse_fname (srcname, dname, fname);
 		get_dependency_list (cx, modname, dflist, MAX_DEPFILES);
 
-		if (!up_to_date (cx, srcname, fname, dflist, &useobj)) {
+		if (!up_to_date (srcname, fname, dflist, &useobj)) {
 
 		    /* If file is remote add its name to the remote file list
 		     * and "checkout" the file, making it accessible in the
@@ -655,12 +655,13 @@ get_dependency_list (
 	    case TOK_NEWLINE:
 		goto done;
 	    case TOK_FNAME:
-		if (nfiles >= MAX_DEPFILES)
+		if (nfiles >= maxfiles)
 		    errors ("too many dependency files for module `%s'", module);
 		dflist[nfiles++] = putstr (fname);
 		break;
 	    case TOK_END:
 		errors ("unexpected EOF in dependency list for `%s'", module);
+		break;
 	    default:
 		errors ("bad token `%s' in dependency list", fname);
 	    }
@@ -696,7 +697,6 @@ done:
  */
 int
 up_to_date (
-  struct context *cx,		/* current library context	*/
   char	*module,		/* module to compare dates for	*/
   char	*lname,			/* local name of module		*/
   char	*dflist[],		/* list of dependent files	*/
