@@ -30,7 +30,6 @@
  */
 
 #define	SZ_KEY		128		/* arbitrary			*/
-extern	int forceupdate;		/* NOT IMPLEMENTED for UNIX	*/
 
 char	mlb_sbuf[SZ_SBUF];		/* string buffer		*/
 int	mlb_op = 0;			/* index into string buffer	*/
@@ -65,7 +64,10 @@ h_scanlibrary (char *library)
 	char	lbuf[SZ_LINE];
 	struct	ar_hdr arf;
 	long	length, fdate;
-	int	len=0, len_arfmag, nmodules;
+	int	len_arfmag, nmodules;
+#if defined(AR_EFMT1) && !defined(__CYGWIN__)
+	int	len=0;
+#endif
 	FILE	*fp;
 	struct stat library_stat;
 
@@ -84,7 +86,6 @@ h_scanlibrary (char *library)
 	/* Open the UNIX archive file.
 	 */
 	if ((fp = fopen (libfname, "r")) == NULL) {
-	    printf ("warning: library `%s' not found\n", libfname);
 	    fflush (stdout);
 	    return (0);
 	}
