@@ -21,7 +21,7 @@ int	verbose;		/* print names of deleted files		*/
 int	execute;		/* permission to delete files		*/
 int	debug;			/* print debugging info			*/
 
-extern	char *vfn2osfn();
+extern	char *vfn2osfn(char *, int);
 
 
 extern int  ZZSTRT (void);
@@ -134,6 +134,7 @@ rmfiles (
 	int	nextn, mode;
 	FILE	*fp = NULL;
 
+
 	if (debug) {
 	    fprintf (stderr, "rmfiles @(%s), exe=%d, ver=%d\n", prog, execute,
 		verbose);
@@ -280,6 +281,12 @@ stripdir (
 	char	fname[SZ_PATHNAME+1];
 	int	deleteit, dp;
 
+	/* Hardwire an exclusion for a .git directory so we don't
+	 * unintentially delete the repo files.
+	 */
+	if (strncmp (".git", dir, 4) == 0)
+	    return;
+
 	if (debug) {
 	    fprintf (stderr, "stripdir %s%s\n", path, dir);
 	    fflush (stderr);
