@@ -5,13 +5,11 @@ include defs
 subroutine errchk
 
 character tok, last_tok, gnbtok, token(MAXTOK)
-integer	ntok
 pointer	mktabl
 include	COMMON_BLOCKS
 string	serrcom1 "logical xerflg, xerpad(84)"
 string	serrcom2 "common /xercom/ xerflg, xerpad"
 
-	ntok = 0
 	tok = 0
 
 	repeat {
