@@ -5,7 +5,6 @@
 subroutine lndict
 
 character sym (MAXTOK), c
-ifdef (UPPERC, character cupper)
 integer sctabl, length
 pointer posn, locn
 include COMMON_BLOCKS
@@ -13,12 +12,10 @@ include COMMON_BLOCKS
    posn = 0
    while (sctabl (namtbl, sym, locn, posn) != EOF)
       if (length(sym) > MAXIDLENGTH) {
-	  ifdef (UPPERC, call outch (BIGC))
-	  ifnotdef (UPPERC, call outch (LETC))
+	  call outch (LETC)
 	  call outtab
 	  for (; mem (locn) != EOS; locn = locn + 1) {
 	     c = mem (locn) # kluge for people with LOGICAL*1 characters
-	     ifdef (UPPERC, c = cupper (c))
 	     call outch (c)
 	  }
 	  call outch (BLANK)
