@@ -5,6 +5,7 @@
 #		-c		Do not call linker, leave relocatables in *.o.
 #		-S		leave assembler output on file.s
 #		-l library	(passed to ld).
+#		-i8		Compile for 8-byte integers
 #		-u		complain about undeclared variables
 #		-w		omit all warning messages
 #		-w66		omit Fortran 66 compatibility warning messages
@@ -43,13 +44,12 @@ set -e
 
 s=/tmp/stderr_$$
 CC=${CC_f2c:-${CC:-cc}}
-CFLAGS="-I${iraf}include -I${iraf}unix/f2c/libf2c ${XC_CFLAGS} -Wno-maybe-uninitialized -Wno-strict-aliasing -Wno-unknown-warning-option -fcommon"
+CFLAGS="-I${iraf}include ${XC_CFLAGS} -std=gnu11 -Wno-deprecated-non-prototype -Wno-maybe-uninitialized -Wno-strict-aliasing -Wno-unknown-warning-option -Wno-return-type -fcommon"
 EFL=${EFL:-/v/bin/efl}
 EFLFLAGS=${EFLFLAGS:-'system=portable deltastno=10'}
 F2C=${F2C:-${iraf}unix/bin/f2c.e}
-F2CFLAGS=${F2CFLAGS:='-KRw8 -Nn802'}
+F2CFLAGS=${F2CFLAGS:='-KRw8 -Nn802 -cf'}
 keepc=0
-warn=1
 xsrc=0
 rc=0
 trap 'rm -f $s ; exit $rc' 0
@@ -135,6 +135,10 @@ do
 		shift
 		;;
 
+	-i8)	F2CFLAGS="$F2CFLAGS -I8"
+		shift
+		;;
+
 	-P)	F2CFLAGS="$F2CFLAGS -P"
 		shift
 		;;
@@ -144,13 +148,11 @@ do
 		;;
 
 	-W*)	CFLAGS="$CFLAGS $1"
-		warn=1
 		shift 1
 		;;
 
 	-w)	F2CFLAGS="$F2CFLAGS -w"
 		CFLAGS="$CFLAGS -w"
-		warn=0
 		case $2 in -6) F2CFLAGS="$F2CFLAGS"66; shift
 			case $2 in -6) shift;; esac;; esac
 		shift
@@ -196,12 +198,7 @@ do
 	*.f)
 		case "$1" in *.f) f=".f";; *.F) f=".F";; esac
 		b=$(basename "$1" $f)
-		if [ $warn = 0 ]; then
-		    $F2C $F2CFLAGS "$b.f" 2>"$s"
-		    sed '/^	arg .*: here/d' "$s" 1>&2
-		else
-		    $F2C $F2CFLAGS "$b.f"
-		fi
+		$F2C $F2CFLAGS "$b.f"
 		if [ $xsrc = 1 ]; then
 		    sed -e "s/$b\\.f/$b.x/" < "$b.c" > "$b.t"; mv "$b.t" "$b.c"
 		fi
