@@ -28,11 +28,6 @@ int pr_getipc (int pid, int *inchan, int *outchan);
 void pr_release (int pid);
 /* zfiobf.c */
 int _u_fmode (int mode);
-int vm_access (char *fname, int mode);
-int vm_delete (char *fname, int force);
-int vm_reservespace (long nbytes);
-int vm_largefile (long nbytes);
-int vm_directio (int fd, int flag);
 /* zfioks.c */
 void pr_mask (char *str);
 /* zpanic.c */
