@@ -13,6 +13,8 @@
 #define	import_knames
 #include <iraf.h>
 
+#include "osproto.h"
+
 /*
  * ZALLOC.C -- Device allocation interface.  Requires the dev$devices table,
  * which is read by the high level code before we are called.
@@ -55,9 +57,6 @@ ZDVALL (
 {
 	PKCHAR	cmd[SZ_LINE+1], nullstr[1];
 
-	extern int ZOSCMD ();
-
-
 	/* Syntax: $host/hlib/alloc.e -[ad] aliases
 	 */
 	strcpy ((char *)cmd, irafpath(ALLOCEXE));
@@ -93,7 +92,7 @@ ZDVOWN (
 {
 	register int	uid;
 	char	*dev, devname[SZ_FNAME+1];
-	struct	passwd *pw, *getpwuid();
+	struct	passwd *pw;
 	struct	stat fi;
 
 
@@ -129,7 +128,6 @@ ZDVOWN (
 	    *status = DV_DEVFREE;
 	else if (uid == getuid())
 	    *status = DV_DEVALLOC;
-	/* else if (!loggedin (uid)) */
 	else if (u_allocstat ((char *)device) == DV_DEVFREE)
 	    *status = DV_DEVFREE;
 	else {
@@ -144,38 +142,6 @@ ZDVOWN (
 }
 
 
-/* LOGGEDIN -- Return 1 if uid is logged in, else 0.
- */
-int
-loggedin (int uid)
-{
-	struct	utmpx ubuf;
-	struct	passwd *pw, *getpwuid();
-	FILE	*ufp;
-
-	if ((ufp = fopen ("/var/run/utmp", "r")) == NULL) {
-	    printf ("zdvown: cannot open /var/run/utmp\n");
-	    return (1);
-	}
-
-	if ((pw = getpwuid (uid)) == NULL) {
-	    fclose (ufp);
-	    return (0);
-	}
-
-	do {
-	    if (fread (&ubuf, sizeof (struct utmpx), 1, ufp) == (size_t) 0) {
-		fclose (ufp);
-		return (0);
-	    }
-	} while (strncmp (ubuf.ut_user, pw->pw_name, 8) != 0);
-
-	fclose (ufp);
-
-	return (1);
-}
-
-
 /* U_ALLOCSTAT -- Call alloc.e to get the device status.  Currently, this has
  * to be done by a priviledged process as the process table is used in some
  * cases.
@@ -188,9 +154,6 @@ u_allocstat (
 	PKCHAR	cmd[SZ_LINE+1], nullstr[1];
 	XINT	x_status;
 
-	extern int ZOSCMD();
-
-
 	/* Syntax: $host/hlib/alloc.e -s aliases
 	 */
 	strcpy ((char *)cmd, irafpath(ALLOCEXE));
