@@ -7,6 +7,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 /* ZFDELE -- Delete a file.
  */
 int
@@ -15,9 +17,6 @@ ZFDELE (
   XINT	  *status
 )
 {
-	extern  int vm_delete(char *fname, int force);
-
-	vm_delete ((char *)fname, 0);
 	if (unlink ((char *)fname) == ERR)
 	    *status = XERR;
 	else
