@@ -8,6 +8,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 /*
  * ZFIOSF -- Static file device driver.  In the 4.1BSD UNIX kernel the ordinary
  * binary file driver is used for static files (files that do not change in
@@ -35,9 +37,6 @@
  * during file creation and deletion.
  */
 
-extern int  ZOPNBF(), ZCLSBF (), ZARDBF (), ZAWRBF (), ZAWTBF (), ZSTTBF ();
-
-
 /* ZOPNSF -- Open a static file.  Only RO, WO, and RW modes are permitted
  * for static files, since allocation is via ZFALOC and appending is not
  * permitted.
