@@ -8,6 +8,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 /* ZFRNAM -- Rename a file.  Do nothing to original file if operation
  * fails.  File must retain all attributes; special action is required
  * to transfer file protection.
@@ -24,8 +26,6 @@ ZFRNAM (
 	static	XINT setprot    = SET_PROTECTION;
 	XINT	protected;
 
-	extern  int ZFPROT(PKCHAR *fname, XINT *action, XINT *status);
-
 
 	/* Most remove file protection before renaming the file, else
 	 * zfprot will not find the file and will refuse to delete the
