@@ -4,6 +4,7 @@
 #include <stdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <utime.h>
 
 #define	import_kernel
@@ -11,6 +12,8 @@
 #define import_spp
 #include <iraf.h>
 
+#include "osproto.h"
+
 #define SECONDS_1970_TO_1980    315532800L
 
 
@@ -29,9 +32,6 @@ ZFUTIM (
 	struct	stat osfile;
 	struct	utimbuf time;
 	XINT	offset = 0;
-	int	stat(), utime();
-
-	extern  int ZGMTCO ();
 
 
 	/* Get UNIX file info.
