@@ -7,7 +7,7 @@
 #define import_spp
 #include <iraf.h>
 
-extern	unsigned VSHLIB[], VSHEND;	/* shared library descriptor */
+#include "osproto.h"
 
 /* ZLOCPR -- Return the entry point address of a procedure as a magic
  * integer value.  A subsequent call to one of the ZCALL primitives is used
@@ -15,7 +15,7 @@ extern	unsigned VSHLIB[], VSHEND;	/* shared library descriptor */
  */
 int
 ZLOCPR (
-  PFI	proc,			/* procedure for which we desire address */
+  funcptr_t	proc,		/* procedure for which we desire address */
   XINT	*o_epa			/* entry point address */
 )
 {
